# This is a core SL6 kickstart designed for docker.
# It will not produce a bootable system
# To use this kickstart, run the following command
# livemedia-creator --make-tar \
#   --iso=/path/to/boot.iso  \
#   --ks=sl6.ks \
#   --image-name=sl6-base.tar.xz
#
# Once the image has been generated, it can be imported into docker
# by using: cat sl6-base.tar.xz | docker import -i imagename

# Basic setup information
url --url="http://mirror.triumf.ca/scientificlinux.org/6/x86_64/os/"
install
keyboard us
lang en_US.UTF-8
rootpw --lock --iscrypted locked
authconfig --enableshadow --passalgo=sha512
timezone --isUtc Etc/UTC
selinux --enforcing
firewall --disabled
network --bootproto=static --device=eth0 --activate --onboot=on --ip=206.12.1.173 --netmask=255.255.255.0 --gateway=206.12.1.252 --nameserver=206.12.1.200
reboot
bootloader --location=none

# Repositories to use
repo --name="sl" --baseurl=http://mirror.triumf.ca/scientificlinux.org/6/x86_64/os/ --cost=100
repo --name="sl-security" --baseurl=http://mirror.triumf.ca/scientificlinux.org/6/x86_64/updates/security/ --cost=100

# Disk setup
zerombr
clearpart --all
part / --size 1200 --fstype ext4


%packages  --excludedocs --nocore --nobase --instLangs=en
@core --nodefaults
yum-plugin-ovl
-*-firmware
-audit
-dhclient
-openssh-server
-yum-autoupdate
-yum-conf-sl6x
%end

%post
exec < /dev/tty > /dev/tty
(
## Post configure tasks for Docker;
## some examples from RHEL6 base image, some from CentOS
set -x

## Set language rpm nodocs tx flags persistently in yum.conf & rpm macros
LANG="en_US"
echo "%_install_lang $LANG" > /etc/rpm/macros.image-language-conf
awk '(NF==0&&!done){print "override_install_langs='$LANG'\ntsflags=nodocs";done=1}{print}' \
    < /etc/yum.conf > /etc/yum.conf.new
mv /etc/yum.conf.new /etc/yum.conf

## Setup locale properly
rm -f /usr/lib/locale/locale-archive
localedef -v -c -i en_US -f UTF-8 en_US.UTF-8 2>/dev/null

## Disable services
for serv in `/sbin/chkconfig|cut -f1`; do /sbin/chkconfig "$serv" off; done;
mv /etc/rc1.d/S26udev-post /etc/rc1.d/K26udev-post

cp /etc/init/rcS.conf /etc/init/rcS.override
sed -i "s#exec /etc/rc.d/rc.sysinit#exec /bin/true#" /etc/init/rcS.override
echo -e "start on stopped rc RUNLEVEL=[]\nenv ACTIVE_CONSOLES=" > /etc/init/start-ttys.override
#sed -i "s#exec /sbin/shutdown -r now \"Control-Alt-Delete pressed\"#exec /sbin/container-shutdown#" /etc/init/control-alt-delete.conf
cat <<EOF > /etc/init.d/killcontainer
#!/bin/bash

kill -s SIGABRT 1
EOF
chmod a+x /etc/init.d/killcontainer
ln -s /etc/init.d/killcontainer /etc/rc.d/rc6.d/S01akillcontainer

# Remove kernel & stuff pulled in by a change to util-linux-ng (rhbz #1349192)
rpm -e --nodeps dracut-kernel dracut grubby grub kbd-misc kbd kernel-firmware kernel

## Clean up
rm -rf /boot
rm -rf /var/cache/yum/*
rm -rf /etc/sysconfig/network-scripts/ifcfg-*

## Generate installtime file record
/bin/date +%Y%m%d_%H%M > /etc/BUILDTIME

set +x
) 2>&1 | tee /var/log/anaconda-post.log

%end

